@@ -97,6 +97,28 @@ class SimultanObject(object):
         # else:
         #     object.__setattr__(self._wrapped_obj, attr, value)
 
+    def __getstate__(self):
+
+        logger.warning(f'__getstate__ in experimental state')
+
+        obj_dict = dict()
+        for key in dir(self.__class__):
+            if type(getattr(self.__class__, key)) is property:
+                print(key)
+                obj_dict[key] = getattr(self, key)
+
+        return obj_dict
+
+    def __setstate__(self, state):
+
+        logger.warning(f'__setstate__ in experimental state')
+
+        for key, value in state.items():
+            try:
+                setattr(self, key, value)
+            except AttributeError as e:
+                pass
+
     @property
     def id(self):
         if self._wrapped_obj is not None:
