@@ -272,6 +272,28 @@ class BaseGeoBaseClass(object):
     def __repr__(self):
         return f'{self.name}: ' + object.__repr__(self)
 
+    def __getstate__(self):
+
+        logger.warning(f'__getstate__ in experimental state')
+
+        obj_dict = dict()
+        for key in dir(self.__class__):
+            if type(getattr(self.__class__, key)) is property:
+                print(key)
+                obj_dict[key] = getattr(self, key)
+
+        return obj_dict
+
+    def __setstate__(self, state):
+
+        logger.warning(f'__setstate__ in experimental state')
+
+        for key, value in state.items():
+            try:
+                setattr(self, key, value)
+            except AttributeError as e:
+                pass
+
 
 class BaseGeometricLayer(BaseGeoBaseClass):
 
@@ -393,7 +415,13 @@ class BaseGeometricFace(BaseGeoBaseClass):
     @property
     def normal(self):
         normal = self._wrapped_obj.get_Normal()
-        return np.array([normal.X, normal.Y, normal.Z])
+        normal_array = np.array([normal.X, normal.Y, normal.Z])
+        if cs_axis_up == 1:
+            return np.array([normal_array[0],normal_array[1], normal_array[2]])
+        elif cs_axis_up == 2:
+            return np.array([-normal_array[0], normal_array[2], normal_array[1]])
+        elif cs_axis_up == 3:
+            return np.array([normal_array[1], normal_array[0], normal_array[2]])
 
     @property
     def orientation(self):
